@@ -4,4 +4,8 @@
 from gistpy.auth import Auth
 from gistpy.query import Query
 from gistpy.dispatch import Dispatcher
-from gistpy.argbuilder import ParserBuilder
\ No newline at end of file
+from gistpy.argbuilder import ParserBuilder
+
+
+def main():
+    Dispatcher().dispatch()
